##  Configuration
The SAP LeanIX for Confluence app is available to download in the Atlassian Marketplace. You can find and install the app directly within your Confluence instance. Once installed, connect the app to your SAP LeanIX workspace via the Confluence administration.
